@@ -1,10 +1,10 @@
-from .context import Context
-from .core import JS
-from .rendering.html import render
-from .core import Component
-from .html import *
+import os
+
+from .version import version as __version__
+
+if not os.environ.get("SEAMLESS_VERSION_ONLY", False):
+    from ._init import *
 
-__version__ = "0.9.0"
 __all__ = [
     "Component",
     "A",
@@ -79,4 +79,5 @@ __all__ = [
     "Context",
     "JS",
     "render",
+    "__version__",
 ]
