@@ -1,10 +1,12 @@
-from .javascript import JavaScript, JS
+from .component import Component
 from .empty import Empty
+from .javascript import JavaScript, JS
 from .sid import SocketID
 
 __all__ = [
+    "Component",
+    "Empty",
     "JavaScript",
     "JS",
-    "Empty",
     "SocketID",
 ]
